summaryrefslogtreecommitdiff
path: root/t/t5411/test-0023-report-unexpect-ref--porcelain.sh
diff options
context:
space:
mode:
authorLibravatar Johannes Schindelin <johannes.schindelin@gmx.de>2020-10-31 19:46:02 +0000
committerLibravatar Junio C Hamano <gitster@pobox.com>2020-10-31 13:15:17 -0700
commita9568dba4177bfe6b75e12a13acd150195e848e0 (patch)
tree518ee6812e8c8672a3f0b2408b916b9e5b118bbd /t/t5411/test-0023-report-unexpect-ref--porcelain.sh
parentt5411: start adjusting the support files for init.defaultBranch=main (diff)
downloadtgif-a9568dba4177bfe6b75e12a13acd150195e848e0.tar.xz
t5411: adjust the remaining support files for init.defaultBranch=main
This trick was performed via $ sed -i -e 's/master/main/g' -e 's/MASTER/MAIN/g' \ -e 's/Master/Main/g' -- t/t5411/* In the previous commit, we adjusted roughly half of the support files, to stay under the 100kB limit (mails larger than that are rejected by the Git mailing list). Signed-off-by: Johannes Schindelin <johannes.schindelin@gmx.de> Signed-off-by: Junio C Hamano <gitster@pobox.com>
Diffstat (limited to 't/t5411/test-0023-report-unexpect-ref--porcelain.sh')
-rw-r--r--t/t5411/test-0023-report-unexpect-ref--porcelain.sh36
1 files changed, 18 insertions, 18 deletions
diff --git a/t/t5411/test-0023-report-unexpect-ref--porcelain.sh b/t/t5411/test-0023-report-unexpect-ref--porcelain.sh
index acbf93e40a..778150fa03 100644
--- a/t/t5411/test-0023-report-unexpect-ref--porcelain.sh
+++ b/t/t5411/test-0023-report-unexpect-ref--porcelain.sh
@@ -2,45 +2,45 @@ test_expect_success "setup proc-receive hook (unexpected ref, $PROTOCOL/porcelai
write_script "$upstream/hooks/proc-receive" <<-EOF
printf >&2 "# proc-receive hook\n"
test-tool proc-receive -v \
- -r "ok refs/heads/master"
+ -r "ok refs/heads/main"
EOF
'
# Refs of upstream : master(A)
# Refs of workbench: master(A) tags/v123
# git push : (B) refs/for/master/topic
test_expect_success "proc-receive: report unexpected ref ($PROTOCOL/porcelain)" '
test_must_fail git -C workbench push --porcelain origin \
- $B:refs/heads/master \
- HEAD:refs/for/master/topic \
+ $B:refs/heads/main \
+ HEAD:refs/for/main/topic \
>out 2>&1 &&
make_user_friendly_and_stable_output <out >actual &&
cat >expect <<-EOF &&
remote: # pre-receive hook
- remote: pre-receive< <COMMIT-A> <COMMIT-B> refs/heads/master
- remote: pre-receive< <ZERO-OID> <COMMIT-A> refs/for/master/topic
+ remote: pre-receive< <COMMIT-A> <COMMIT-B> refs/heads/main
+ remote: pre-receive< <ZERO-OID> <COMMIT-A> refs/for/main/topic
remote: # proc-receive hook
- remote: proc-receive< <ZERO-OID> <COMMIT-A> refs/for/master/topic
- remote: proc-receive> ok refs/heads/master
- remote: error: proc-receive reported status on unexpected ref: refs/heads/master
+ remote: proc-receive< <ZERO-OID> <COMMIT-A> refs/for/main/topic
+ remote: proc-receive> ok refs/heads/main
+ remote: error: proc-receive reported status on unexpected ref: refs/heads/main
remote: # post-receive hook
- remote: post-receive< <COMMIT-A> <COMMIT-B> refs/heads/master
+ remote: post-receive< <COMMIT-A> <COMMIT-B> refs/heads/main
To <URL/of/upstream.git>
- <COMMIT-B>:refs/heads/master <OID-A>..<OID-B>
- ! HEAD:refs/for/master/topic [remote rejected] (proc-receive failed to report status)
+ <COMMIT-B>:refs/heads/main <OID-A>..<OID-B>
+ ! HEAD:refs/for/main/topic [remote rejected] (proc-receive failed to report status)
Done
EOF
test_cmp expect actual &&
git -C "$upstream" show-ref >out &&
make_user_friendly_and_stable_output <out >actual &&
cat >expect <<-EOF &&
- <COMMIT-B> refs/heads/master
+ <COMMIT-B> refs/heads/main
EOF
test_cmp expect actual
'
# Refs of upstream : master(B)
# Refs of workbench: master(A) tags/v123
test_expect_success "cleanup ($PROTOCOL/porcelain)" '
- git -C "$upstream" update-ref refs/heads/master $A
+ git -C "$upstream" update-ref refs/heads/main $A
'
@@ -2,45 +2,45 @@ test_expect_success "setup proc-receive hook (unexpected ref, $PROTOCOL/porcelai
EOF
'
-# Refs of upstream : master(A)
-# Refs of workbench: master(A) tags/v123
-# git push : (B) refs/for/master/topic
+# Refs of upstream : main(A)
+# Refs of workbench: main(A) tags/v123
+# git push : (B) refs/for/main/topic
test_expect_success "proc-receive: report unexpected ref ($PROTOCOL/porcelain)" '
test_must_fail git -C workbench push --porcelain origin \
@@ -2,45 +2,45 @@ test_expect_success "setup proc-receive hook (unexpected ref, $PROTOCOL/porcelai
test_cmp expect actual
'
-# Refs of upstream : master(B)
-# Refs of workbench: master(A) tags/v123
+# Refs of upstream : main(B)
+# Refs of workbench: main(A) tags/v123
test_expect_success "cleanup ($PROTOCOL/porcelain)" '